==> apache-cxf-3.6.6-src.tar.gz: apache-cxf-3.6.6-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/validation/MultipartBookStoreWithValidation.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs.validation;

import javax.validation.Valid;
import javax.ws.rs.Consumes;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import org.apache.cxf.jaxrs.ext.multipart.Attachment;
import org.apache.cxf.jaxrs.ext.multipart.Multipart;

@Path("/bookstore")
public class MultipartBookStoreWithValidation {
    @POST
    @Path("/books/details")
    @Consumes("multipart/form-data")
    @Produces("text/xml")
    public Response addBookWithDetails(
            @Valid @Multipart(value = "book", type = "application/xml") BookWithValidation book,
            @Multipart("upfile1Detail") Attachment a1,
            @Multipart("upfile2Detail") Attachment a2,
            @Multipart("upfile3Detail") Attachment a3)
        throws Exception {

        if (a1.equals(a2) || a1.equals(a3) || a2.equals(a3)) {
            throw new WebApplicationException();
        }

        book.setName(a1.getContentId() + "," + a2.getContentId() + "," + a3.getContentId());
        return Response.ok(book, MediaType.APPLICATION_XML_TYPE).build();
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/validation/MultipartBookStoreWithValidation.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs.validation;

import jakarta.validation.Valid;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.WebApplicationException;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;
import org.apache.cxf.jaxrs.ext.multipart.Attachment;
import org.apache.cxf.jaxrs.ext.multipart.Multipart;

@Path("/bookstore")
public class MultipartBookStoreWithValidation {
    @POST
    @Path("/books/details")
    @Consumes("multipart/form-data")
    @Produces("text/xml")
    public Response addBookWithDetails(
            @Valid @Multipart(value = "book", type = "application/xml") BookWithValidation book,
            @Multipart("upfile1Detail") Attachment a1,
            @Multipart("upfile2Detail") Attachment a2,
            @Multipart("upfile3Detail") Attachment a3)
        throws Exception {

        if (a1.equals(a2) || a1.equals(a3) || a2.equals(a3)) {
            throw new WebApplicationException();
        }

        book.setName(a1.getContentId() + "," + a2.getContentId() + "," + a3.getContentId());
        return Response.ok(book, MediaType.APPLICATION_XML_TYPE).build();
    }
}
